splitn

Function splitn 

pub fn splitn<'a, T>(
    s: &'a T,
    escape_char: char,
    n: usize,
    sep: char,
) -> impl Iterator<Item = &'a str> + use<'a, T>
where T: AsRef<str> + ?Sized,
split the string into at most n parts separated by non escaped instances of sep and return an iterator over the parts